@@ -1,4 +1,4 @@
-(define-constant banner #<<EOF
+(define banner #<<EOF
 
   ___| |    _)      |               
  |     __ \  |  __| |  /  _ \ __ \  
@@ -8,5 +8,3 @@
 
 EOF
 )
-
-(define-constant copyright "(c)2000-2006 Felix L. Winkelmann")
